package com.adzel.velocitybroadcast;

import com.adzel.velocitybroadcast.util.DatabaseManager;
import com.adzel.velocitybroadcast.util.UpdateChecker;
import com.velocitypowered.api.event.Subscribe;
import com.velocitypowered.api.event.connection.PostLoginEvent;
import com.velocitypowered.api.proxy.Player;
import com.velocitypowered.api.proxy.ProxyServer;

import net.kyori.adventure.text.Component;
import net.kyori.adventure.text.minimessage.MiniMessage;

public class LoginListener {
    private final ProxyServer server;
    private final String currentVersion;
    private final UpdateChecker updateChecker;
    private final DatabaseManager databaseManager;

    private static final MiniMessage MINI_MESSAGE = MiniMessage.miniMessage();

    public LoginListener(ProxyServer server, String currentVersion, UpdateChecker updateChecker, DatabaseManager databaseManager) {
        this.server = server;
        this.currentVersion = currentVersion;
        this.updateChecker = updateChecker;
        this.databaseManager = databaseManager;
    }

    @Subscribe
    public void onPlayerJoin(PostLoginEvent event) {
        Player player = event.getPlayer();
        if (player.hasPermission("vb.admin")) {
            // ✅ Log admin join to DB
            String serverName = server.getBoundAddress().toString(); // Optional
            databaseManager.logAdminJoin(player.getUsername(), serverName);

            // ✅ Notify if update is available
            updateChecker.checkForUpdate().thenAccept(latest -> {
                if (latest != null && !latest.equalsIgnoreCase(currentVersion)) {
                    Component message = MINI_MESSAGE.deserialize(
                        "<bold><gold>[VelocityBroadcast]</gold></bold> " +
                        "<gradient:yellow:red>A new version is available: </gradient:yellow:red>" +
                        "<bold><green>" + latest + "</green></bold> " +
                        "<gray>(You are on <red>" + currentVersion + "</red>)</gray>"
                    );
                    player.sendMessage(message);
                }
            });
        }
    }
}
